@@ -15,8 +15,9 @@ import random
 
 import mock
 from mock import call
+
+from osc_lib.cli import format_columns
 from osc_lib import exceptions
-from osc_lib import utils
 
 from openstackclient.network.v2 import network
 from openstackclient.tests.unit import fakes
@@ -60,10 +61,12 @@ class TestCreateNetworkIdentityV3(TestNetwork):
         'availability_zone_hints',
         'availability_zones',
         'description',
+        'dns_domain',
         'id',
         'ipv4_address_scope',
         'ipv6_address_scope',
         'is_default',
+        'mtu',
         'name',
         'port_security_enabled',
         'project_id',
@@ -79,14 +82,16 @@ class TestCreateNetworkIdentityV3(TestNetwork):
     )
 
     data = (
-        network._format_admin_state(_network.admin_state_up),
-        utils.format_list(_network.availability_zone_hints),
-        utils.format_list(_network.availability_zones),
+        network.AdminStateColumn(_network.admin_state_up),
+        format_columns.ListColumn(_network.availability_zone_hints),
+        format_columns.ListColumn(_network.availability_zones),
         _network.description,
+        _network.dns_domain,
         _network.id,
         _network.ipv4_address_scope_id,
         _network.ipv6_address_scope_id,
         _network.is_default,
+        _network.mtu,
         _network.name,
         _network.is_port_security_enabled,
         _network.project_id,
@@ -94,11 +99,11 @@ class TestCreateNetworkIdentityV3(TestNetwork):
         _network.provider_physical_network,
         _network.provider_segmentation_id,
         _network.qos_policy_id,
-        network._format_router_external(_network.is_router_external),
+        network.RouterExternalColumn(_network.is_router_external),
         _network.shared,
         _network.status,
-        utils.format_list(_network.subnets),
-        utils.format_list(_network.tags),
+        format_columns.ListColumn(_network.subnets),
+        format_columns.ListColumn(_network.tags),
     )
 
     def setUp(self):
@@ -142,13 +147,14 @@ class TestCreateNetworkIdentityV3(TestNetwork):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_all_options(self):
         arglist = [
             "--disable",
             "--share",
             "--description", self._network.description,
+            "--mtu", self._network.mtu,
             "--project", self.project.name,
             "--project-domain", self.domain.name,
             "--availability-zone-hint", "nova",
@@ -159,12 +165,14 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             "--qos-policy", self.qos_policy.id,
             "--transparent-vlan",
             "--enable-port-security",
+            "--dns-domain", "example.org.",
             self._network.name,
         ]
         verifylist = [
             ('disable', True),
             ('share', True),
             ('description', self._network.description),
+            ('mtu', self._network.mtu),
             ('project', self.project.name),
             ('project_domain', self.domain.name),
             ('availability_zone_hints', ["nova"]),
@@ -177,6 +185,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             ('transparent_vlan', True),
             ('enable_port_security', True),
             ('name', self._network.name),
+            ('dns_domain', 'example.org.'),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -188,6 +197,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             'name': self._network.name,
             'shared': True,
             'description': self._network.description,
+            'mtu': self._network.mtu,
             # TODO(dtroyer): Remove tenant_id when we clean up the SDK refactor
             'tenant_id': self.project.id,
             'project_id': self.project.id,
@@ -199,9 +209,10 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             'qos_policy_id': self.qos_policy.id,
             'vlan_transparent': True,
             'port_security_enabled': True,
+            'dns_domain': 'example.org.',
         })
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_other_options(self):
         arglist = [
@@ -228,7 +239,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             'port_security_enabled': False,
         })
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def _test_create_with_tag(self, add_tags=True):
         arglist = [self._network.name]
@@ -260,7 +271,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
         else:
             self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True)
@@ -282,10 +293,12 @@ class TestCreateNetworkIdentityV2(TestNetwork):
         'availability_zone_hints',
         'availability_zones',
         'description',
+        'dns_domain',
         'id',
         'ipv4_address_scope',
         'ipv6_address_scope',
         'is_default',
+        'mtu',
         'name',
         'port_security_enabled',
         'project_id',
@@ -301,14 +314,16 @@ class TestCreateNetworkIdentityV2(TestNetwork):
     )
 
     data = (
-        network._format_admin_state(_network.admin_state_up),
-        utils.format_list(_network.availability_zone_hints),
-        utils.format_list(_network.availability_zones),
+        network.AdminStateColumn(_network.admin_state_up),
+        format_columns.ListColumn(_network.availability_zone_hints),
+        format_columns.ListColumn(_network.availability_zones),
         _network.description,
+        _network.dns_domain,
         _network.id,
         _network.ipv4_address_scope_id,
         _network.ipv6_address_scope_id,
         _network.is_default,
+        _network.mtu,
         _network.name,
         _network.is_port_security_enabled,
         _network.project_id,
@@ -316,11 +331,11 @@ class TestCreateNetworkIdentityV2(TestNetwork):
         _network.provider_physical_network,
         _network.provider_segmentation_id,
         _network.qos_policy_id,
-        network._format_router_external(_network.is_router_external),
+        network.RouterExternalColumn(_network.is_router_external),
         _network.shared,
         _network.status,
-        utils.format_list(_network.subnets),
-        utils.format_list(_network.tags),
+        format_columns.ListColumn(_network.subnets),
+        format_columns.ListColumn(_network.tags),
     )
 
     def setUp(self):
@@ -371,7 +386,7 @@ class TestCreateNetworkIdentityV2(TestNetwork):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_with_domain_identityv2(self):
         arglist = [
@@ -511,7 +526,7 @@ class TestListNetwork(TestNetwork):
         data.append((
             net.id,
             net.name,
-            utils.format_list(net.subnets),
+            format_columns.ListColumn(net.subnets),
         ))
 
     data_long = []
@@ -521,13 +536,13 @@ class TestListNetwork(TestNetwork):
             net.name,
             net.status,
             net.project_id,
-            network._format_admin_state(net.admin_state_up),
+            network.AdminStateColumn(net.admin_state_up),
             net.shared,
-            utils.format_list(net.subnets),
+            format_columns.ListColumn(net.subnets),
             net.provider_network_type,
-            network._format_router_external(net.is_router_external),
-            utils.format_list(net.availability_zones),
-            utils.format_list(net.tags),
+            network.RouterExternalColumn(net.is_router_external),
+            format_columns.ListColumn(net.availability_zones),
+            format_columns.ListColumn(net.tags),
         ))
 
     def setUp(self):
@@ -563,7 +578,7 @@ class TestListNetwork(TestNetwork):
 
         self.network.networks.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_list_external(self):
         arglist = [
@@ -584,7 +599,7 @@ class TestListNetwork(TestNetwork):
             **{'router:external': True, 'is_router_external': True}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_list_internal(self):
         arglist = [
@@ -601,7 +616,7 @@ class TestListNetwork(TestNetwork):
             **{'router:external': False, 'is_router_external': False}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_long(self):
         arglist = [
@@ -620,7 +635,7 @@ class TestListNetwork(TestNetwork):
 
         self.network.networks.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertEqual(self.data_long, list(data))
+        self.assertListItemEqual(self.data_long, list(data))
 
     def test_list_name(self):
         test_name = "fakename"
@@ -639,7 +654,7 @@ class TestListNetwork(TestNetwork):
             **{'name': test_name}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_enable(self):
         arglist = [
@@ -657,7 +672,7 @@ class TestListNetwork(TestNetwork):
             **{'admin_state_up': True, 'is_admin_state_up': True}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_disable(self):
         arglist = [
@@ -675,7 +690,7 @@ class TestListNetwork(TestNetwork):
             **{'admin_state_up': False, 'is_admin_state_up': False}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_project(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -694,7 +709,7 @@ class TestListNetwork(TestNetwork):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_project_domain(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -713,7 +728,7 @@ class TestListNetwork(TestNetwork):
 
         self.network.networks.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_share(self):
         arglist = [
@@ -730,7 +745,7 @@ class TestListNetwork(TestNetwork):
             **{'shared': True, 'is_shared': True}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_no_share(self):
         arglist = [
@@ -747,7 +762,7 @@ class TestListNetwork(TestNetwork):
             **{'shared': False, 'is_shared': False}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_status(self):
         choices = ['ACTIVE', 'BUILD', 'DOWN', 'ERROR']
@@ -766,7 +781,7 @@ class TestListNetwork(TestNetwork):
             **{'status': test_status}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_provider_network_type(self):
         network_type = self._network[0].provider_network_type
@@ -784,7 +799,7 @@ class TestListNetwork(TestNetwork):
                'provider_network_type': network_type}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_provider_physical_network(self):
         physical_network = self._network[0].provider_physical_network
@@ -802,7 +817,7 @@ class TestListNetwork(TestNetwork):
                'provider_physical_network': physical_network}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_provider_segment(self):
         segmentation_id = self._network[0].provider_segmentation_id
@@ -820,7 +835,7 @@ class TestListNetwork(TestNetwork):
                'provider_segmentation_id': segmentation_id}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_network_list_dhcp_agent(self):
         arglist = [
@@ -839,7 +854,7 @@ class TestListNetwork(TestNetwork):
             *attrs)
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(list(data), list(self.data))
+        self.assertListItemEqual(list(data), list(self.data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -864,7 +879,7 @@ class TestListNetwork(TestNetwork):
                'not_any_tags': 'black,white'}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
 
 class TestSetNetwork(TestNetwork):
@@ -894,6 +909,7 @@ class TestSetNetwork(TestNetwork):
             '--name', 'noob',
             '--share',
             '--description', self._network.description,
+            '--dns-domain', 'example.org.',
             '--external',
             '--default',
             '--provider-network-type', 'vlan',
@@ -915,6 +931,7 @@ class TestSetNetwork(TestNetwork):
             ('segmentation_id', '400'),
             ('enable_port_security', True),
             ('qos_policy', self.qos_policy.name),
+            ('dns_domain', 'example.org.'),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -932,6 +949,7 @@ class TestSetNetwork(TestNetwork):
             'provider:segmentation_id': '400',
             'port_security_enabled': True,
             'qos_policy_id': self.qos_policy.id,
+            'dns_domain': 'example.org.',
         }
         self.network.update_network.assert_called_once_with(
             self._network, **attrs)
@@ -1019,10 +1037,12 @@ class TestShowNetwork(TestNetwork):
         'availability_zone_hints',
         'availability_zones',
         'description',
+        'dns_domain',
         'id',
         'ipv4_address_scope',
         'ipv6_address_scope',
         'is_default',
+        'mtu',
         'name',
         'port_security_enabled',
         'project_id',
@@ -1038,14 +1058,16 @@ class TestShowNetwork(TestNetwork):
     )
 
     data = (
-        network._format_admin_state(_network.admin_state_up),
-        utils.format_list(_network.availability_zone_hints),
-        utils.format_list(_network.availability_zones),
+        network.AdminStateColumn(_network.admin_state_up),
+        format_columns.ListColumn(_network.availability_zone_hints),
+        format_columns.ListColumn(_network.availability_zones),
         _network.description,
+        _network.dns_domain,
         _network.id,
         _network.ipv4_address_scope_id,
         _network.ipv6_address_scope_id,
         _network.is_default,
+        _network.mtu,
         _network.name,
         _network.is_port_security_enabled,
         _network.project_id,
@@ -1053,11 +1075,11 @@ class TestShowNetwork(TestNetwork):
         _network.provider_physical_network,
         _network.provider_segmentation_id,
         _network.qos_policy_id,
-        network._format_router_external(_network.is_router_external),
+        network.RouterExternalColumn(_network.is_router_external),
         _network.shared,
         _network.status,
-        utils.format_list(_network.subnets),
-        utils.format_list(_network.tags),
+        format_columns.ListColumn(_network.subnets),
+        format_columns.ListColumn(_network.tags),
     )
 
     def setUp(self):
@@ -1090,7 +1112,7 @@ class TestShowNetwork(TestNetwork):
             self._network.name, ignore_missing=False)
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
 
 class TestUnsetNetwork(TestNetwork):
